# AT93c46_16
#
# EEPROM uses SPI interface with a 26 bit address and 8 bit read

class at93c46_8:
    configured = 0
    size = 128
    def __init__(self,sObj):
        self.bv4 = sObj
    # ------------------------------------------------------------------------------
    # returns values about this device
    # ------------------------------------------------------------------------------
    def get_notes(self):
        rv = "This is an SPI device that can be read as 8\n\
or 16 bits of data. This device has the ORG pin\n\
set low and so it is 8 bit data\n"
        return rv
    def get_type(self):       
        return 1 # SPI is 1 i2c 2
    def get_bit_size(self):
        return  8
    def get_bytes(self):
        return self.size # number of total bytes in eeprom 

    # ------------------------------------------------------------------------------
    # configures to serial device, serial device already connected to 
    # serial port
    # ------------------------------------------------------------------------------
    def config(self):
        self.bv4.Spi() # SPI mode
        self.EWEN() # enable write
        self.configured = 1

    # ------------------------------------------------------------------------------
    # Erase / Write enable
    # ------------------------------------------------------------------------------
    def EWEN(self):
        self.bv4.Write("h1\r") # CS-H
        self.bv4.Write("na\r") # set to 10 bits
        self.bv4.Write("260\r") # o/p 10 bits
        self.bv4.Write("l1\r") # CS-L
        
    # ------------------------------------------------------------------------------
    # erase all
    # ------------------------------------------------------------------------------
    def erase_all(self):
        self.bv4.Write("h1\r") # CS-H
        self.bv4.Write("na\r") # set to 10 bits
        self.bv4.Write("240\r") # o/p 10 bits erase all command
        self.bv4.Write("l1\r") # CS-L
    
    
    # ------------------------------------------------------------------------------
    # sends data to the spi in the correct format, will also return a value
    # Must be in SPI mode
    # ------------------------------------------------------------------------------
    def read(self,register):
        rv = 'ff'
        if register+1 > self.size:
            return rv
        r = 0
        self.bv4.Write("na\r") # set to 10 bits
        r = 0x300 + register # high + opcode + address
        #print "r={}".format(str(hex(r))[2:])
        self.bv4.Write("h1\r") # CS-H
        self.bv4.Write(str(hex(r))[2:]+"\r") # o/p 10 bits
        self.bv4.Write("n8\r") # set to 8 bits
        rv =self.bv4.Write("ffff\r") # o/p and read 8 bits
        self.bv4.Write("l1\r") # CS-L
        return rv
    
    # ------------------------------------------------------------------------------
    # write 16 bit value to register
    # ------------------------------------------------------------------------------
    def write(self,register, value): 
        if register+1 > self.size:
            return
        r = 0
        self.bv4.Write("na\r") # set to 10 bits
        r = 0x280 + register # high + opcode + address
        #print "r={}".format(str(hex(r))[2:])
        self.bv4.Write("h1\r") # CS-H
        self.bv4.Write(str(hex(r))[2:]+"\r") # o/p 10 bits
        self.bv4.Write("n8\r") # set to 8 bits
        self.bv4.Write(str(hex(value))[2:]+"\r") # o/p 8 bits
        self.bv4.Write("l1\r") # CS-L

   
    