# 24c16 I2C 16k bit (2 k byte EEPROM)
#
# EEPROM uses SPI interface with a 25 bit address and 16 bit read

class m24c16:
    configured = 0
    adr = None
    size = 2048
    def __init__(self,sObj):
        self.bv4 = sObj
    # ------------------------------------------------------------------------------
    # returns values about this device
    # ------------------------------------------------------------------------------
    def get_notes(self):
        rv = "This is an I2C device with 2048 bytes, it uses\n\
the I2C address to address the internal memory\n\
and so has 8 I2C addresses 0xa0 to 0xae"
        return rv
    def get_type(self):       
        return 2 # SPI is 1 i2c 2
    def get_bit_size(self):
        return  8
    def get_bytes(self):
        return self.size # number of total bytes in eeprom     

    # ------------------------------------------------------------------------------
    # configures to serial device, serial device already connected to 
    # serial port. Sets base address which is needed for reading as the 'r'
    # command calculates baseaddress + 1
    # ------------------------------------------------------------------------------
    def config(self):
        self.adr = self.bv4.I2c() # I2c mode
        if len(self.adr) > 0:
            self.bv4.Write("A"+self.adr+"\r") # also set base adress
        self.configured = 1

    # ------------------------------------------------------------------------------
    # reads data from specified memory address
    # the device address will depend on the memory address so 
    # a0 is 0 to 255
    # a2 id 256 to 511 etc.
    # ------------------------------------------------------------------------------
    def read(self,address):
        rv = 'ff'
        if address+1 > self.size:
            return rv
        offset = address/256
        i2cadr = (offset*2) + int(self.adr,16) # calc i2c address from memory address
        memadr = address - (offset * 256)
        hxadr = hex(i2cadr)[2:] # suitable for input to bv4221
        hxmem = hex(memadr)[2:]
        #print "memadr=%d" % memadr
        #print "hxadr=%s"  % hxadr
        #print "ss=%s" % "s-"+hxadr+" "+hxmem+" r g-1 p\r"
        if self.adr != None:
            rv = self.bv4.Write("s-"+hxadr+" "+hxmem+" r g-1 p\r" ) # read 1 byte 
        return rv
    
    # ------------------------------------------------------------------------------
    # write byte to address
    # ------------------------------------------------------------------------------
    def write(self,address, value): 
        if address+1 > self.size:
            return
        offset = address/256
        i2cadr = (offset*2) + int(self.adr,16) # calc i2c address from memory address
        memadr = address - (offset * 256)
        hxadr = hex(i2cadr)[2:] # suitable for input to bv4221
        hxmem = hex(memadr)[2:]
        hxvalue = hex(value)[2:]
        #print "ss=%s" % "s-"+hxadr+" "+hxmem+" "+hxvalue+"p\r"
        self.bv4.Write("s-"+hxadr+" "+hxmem+" "+hxvalue+"p\r")

   
    