# bv4221.py
#
# Verion 1.0
#
# BEFORE USING
# The BV4221 needs to be attached to a console first and the following commands
# are required for use with this software
# P0    // tuns off the prompt
# F     // fixes this behaviour
#
# The serial communication in Python is by defualt text, text is sent and text
# is recieved so in the following code chr() and ord() is used to do the
# conversions
#
# To keep the code simple and easy to read, no range checking is done, you may
# want to add this later.
#
#
import serial
import sys
from time import sleep

# Change to suit O/S
# RPI
#sp=serial.Serial("/dev/ttyAMA0", 38400, timeout=2, stopbits=1, parity='N' )
# Windows
#sp=serial.Serial("COM6", 38400, timeout=2, stopbits=1, parity='N' )

class bv4221:
    "Class using COM port to drive BV4221"
    sp = None
    connected = 0
    ACK =''
    def __init__(self):
        self.ACK = "*"
        self.sp = None
    # ------------------------------------------------------------------------------
    # Initialise device, this will only return sucess on the first initialisation
    # will ignore subsiquent initialisations. This should be done after reset as
    # it establishes communication with the device. If the baud rate has been fixed
    # then this is not needed however the port still needs opening, obviously
    # return 0 on sucess
    # ------------------------------------------------------------------------------
    def Init(self,port,baud):
        sucess = 0
        if self.sp != None:
            if self.sp.isOpen()== True:
                self.sp.close()
        self.sp=serial.Serial(port, baud, timeout=2, stopbits=1, parity='N' )
        sleep(2) # opening port initialises so wait
        # send a couple of CR, the prompt for this device is '>'
        self.sp.write("\r")
        sleep(0.05)
        self.sp.write("\r")
        sleep(0.10)
        self.sp.flushInput() # flush here
        self.sp.write("\r")
        if self.Wack() == 0:
            self.connected = 1
            return 0
        else:
            return 1

    # ------------------------------------------------------------------------------
    # for commands that just return ACK,
    # return 0 on sucess
    # ------------------------------------------------------------------------------
    def Wack(self):
        k = self.sp.read(1)
        if k == self.ACK:
            return 0
        return 1
            
    # ------------------------------------------------------------------------------
    # reads characters up to ACK and returns them
    # note will return a string
    # ------------------------------------------------------------------------------
    def Read(self):
        k = '' 
        v = ''
        while k != self.ACK:
            k = self.sp.read(1)
            if len(k) == 0: # timeout
                break
            if k != self.ACK:
                v = v + k
        return v
        
    # ------------------------------------------------------------------------------
    # send a command string and return with result
    # ------------------------------------------------------------------------------
    def Write(self,cmd):
        self.sp.flushInput()
        self.sp.write(cmd)
        return self.Read()
    
    # ------------------------------------------------------------------------------
    # Set up SPI
    # ------------------------------------------------------------------------------
    def Spi(self):
        self.Write("S\r") # SPI mode
        self.Write("H\r") # all hex
        self.Write("P0\r") # turn off promts, just in case

    # ------------------------------------------------------------------------------
    # Set up I2C and return the first address as a string
    # ------------------------------------------------------------------------------
    def I2c(self):
        adr =''
        self.Write("I\r") # I2C mode
        self.Write("H\r") # all hex
        self.Write("P0\r") # turn off promts, just in case
        adr = self.Write("x\r") # get address
        return adr[:2]

    # ------------------------------------------------------------------------------
    # Closes connection
    # ------------------------------------------------------------------------------
    def Close(self):
        if self.sp != None:
            if self.sp.isOpen()== True:
                self.sp.close()


    